@@ -1,9 +1,9 @@
 /* -*-mode:C;tab-width:3-*-
  * gpm.h - public include file for gpm
  *
- * Copyright 1994,1995   rubini@linux.it (Alessandro Rubini)
- * Copyright (C) 1998 Ian Zimmerman <itz@rahul.net>
- * Copyright (C) 2002 Nico Schottelius <nico@schottelius.org>
+ * Copyright 1994,1995     rubini@linux.it (Alessandro Rubini)
+ * Copyright 1998          Ian Zimmerman <itz@rahul.net>
+ * Copyright 2002-2008     Nico Schottelius <nico-gpm2008 at schottelius.org>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,8 +23,6 @@
 #ifndef _GPM_H_
 #define _GPM_H_
 
-/* $Id: gpm.h,v 1.5 2001/04/23 09:47:00 nicos Exp $ */
-
 #include <paths.h>              /* _PATH_VARRUN etc. */
 
 #ifdef __cplusplus
@@ -35,7 +33,7 @@ extern "C" {
 
 #define GPM_XTERM_ON \
   printf("%c[?1001s",27), fflush(stdout), /* save old hilit tracking */ \
-  printf("%c[?1000h",27), fflush(stdout) /* enable mouse tracking */
+  printf("%c[?1000h",27), fflush(stdout)  /* enable mouse tracking */
 
 #define GPM_XTERM_OFF \
   printf("%c[?1000l",27), fflush(stdout), /* disable mouse tracking */ \
@@ -54,9 +52,6 @@ extern "C" {
 #endif
 
 #define GPM_NODE_DIR      _PATH_VARRUN
-/* unneeded since gpm-1.20.0
-#define GPM_NODE_FILE     GPM_NODE_DIR "gpmXXXXXX"
-*/
 
 /* itz Wed Jul  1 11:56:46 PDT 1998 this definitely ought not to be
    world-writable; umask doesn't apply either, as gpm is most often
@@ -75,6 +70,17 @@ extern "C" {
 #define GPM_NODE_FIFO     _PATH_DEV	"gpmdata"
 
 /*....................................... Cfg buttons */
+/* Each button has one bit in the 16 bit buttons field.
+ * Mouse movement and wheel movement are not associated with a button
+ * i.e. buttons=GPM_B_NONE in these cases
+ * (except for ms3 mouse, for reasons unknown?)
+ * The middle button if pressed down (or clicked) is independent of 
+ *  the wheel "device" which it happens to be associated with
+ * The use of GPM_B_UP/DOWN with ms3 is unclear. Maybe the wheel 
+ * could be rolled forward then backward
+ * and this would generate a 'click' event on 'button 5' GPM_B_UP,
+ * but really the expected behaviour of wheel is movement, typically
+ * used for jump scrolling or for jumping between fields on a form. */
 
 #define GPM_B_DOWN      32
 #define GPM_B_UP        16
@@ -82,6 +88,14 @@ extern "C" {
 #define GPM_B_LEFT      4
 #define GPM_B_MIDDLE    2
 #define GPM_B_RIGHT     1
+#define GPM_B_NONE      0
+
+/*................................... Strange requests (iff conn->pid==0)*/
+
+#define GPM_REQ_SNAPSHOT 0
+#define GPM_REQ_BUTTONS  1
+#define GPM_REQ_CONFIG   2
+#define GPM_REQ_NOPASTE  3
 
 /*....................................... The event types */
 
@@ -121,10 +135,18 @@ enum Gpm_Margin {GPM_TOP=1, GPM_BOT=2, GPM_LFT=4, GPM_RGT=8};
 typedef struct Gpm_Event {
   unsigned char buttons, modifiers;  /* try to be a multiple of 4 */
   unsigned short vc;
-  short dx, dy, x, y;
+  short dx, dy, x, y; /* displacement x,y for this event, and absolute x,y */
   enum Gpm_Etype type;
+  /* clicks e.g. double click are determined by time-based processing */
   int clicks;
   enum Gpm_Margin margin;
+  /* wdx/y: displacement of wheels in this event. Absolute values are not 
+   * required, because wheel movement is typically used for scrolling
+   * or selecting fields, not for cursor positioning. The application
+   * can determine when the end of file or form is reached, and not
+   * go any further. 
+   * A single mouse will use wdy, "vertical scroll" wheel. */
+  short wdx, wdy;
 }              Gpm_Event;
 
 /*....................................... The handling function */
@@ -254,7 +276,7 @@ char *Gpm_GetLibVersion(int *where);
 char *Gpm_GetServerVersion(int *where);
 int   Gpm_GetSnapshot(Gpm_Event *ePtr);
 
-/* tools.c */
+/* tools.c: do they really need to be exported? Can't we keep them in gpmInt.h ? */
 char *Gpm_get_console( void );
 int Gpm_x_high_y(int base, int pot_y);
 int Gpm_cnt_digits(int number);
